@@ -20,12 +20,12 @@
 #include <lttoolbox/alphabet.h>
 #include <lttoolbox/regexp_compiler.h>
 #include <lttoolbox/entry_token.h>
-#include <lttoolbox/ltstr.h>
 #include <lttoolbox/transducer.h>
 
 #include <map>
 #include <string>
 #include <set>
+#include <cstdint>
 #include <libxml/xmlreader.h>
 
 using namespace std;
@@ -39,89 +39,107 @@ private:
     /**
      * The libxml2's XML reader
      */
-    xmlTextReaderPtr reader;
+    xmlTextReaderPtr reader = nullptr;
 
     /**
      * The alt value
      */
-    wstring alt;
+    UString alt;
 
     /**
      * The variant value (monodix)
      */
-    wstring variant;
+    UString variant;
 
     /**
      * The variant value (left side of bidix)
      */
-    wstring variant_left;
+    UString variant_left;
 
     /**
      * The variant value (right side of bidix)
      */
-    wstring variant_right;
+    UString variant_right;
 
     /**
      * The paradigm being compiled
      */
-    wstring current_paradigm;
+    UString current_paradigm;
 
     /**
      * The dictionary section being compiled
      */
-    wstring current_section;
+    UString current_section;
 
     /**
      * The direction of the compilation, 'lr' (left-to-right) or 'rl'
      * (right-to-left)
      */
-    wstring direction;
+    UString direction;
 
     /**
      * List of characters to be considered alphabetic
      */
-    wstring letters;
+    UString letters;
 
     /**
      * Set verbose mode: warnings which may or may not be correct
      */
-    bool verbose;
+    bool verbose = false;
 
     /**
      * First element (of an entry)
      */
-    bool first_element;
+    bool first_element = false;
 
     /**
      * Identifier of all the symbols during the compilation
      */
     Alphabet alphabet;
 
+    /**
+     * Special symbols
+     */
+    int32_t any_tag = 0;
+    int32_t any_char = 0;
+    int32_t word_boundary = 0;
+    int32_t word_boundary_s = 0;
+    int32_t word_boundary_ns = 0;
+
     /**
      * List of named transducers-paradigms
      */
-    map<wstring, Transducer, Ltstr> paradigms;
+    map<UString, Transducer> paradigms;
 
     /**
      * List of named dictionary sections
      */
-    map<wstring, Transducer, Ltstr> sections;
+    map<UString, Transducer> sections;
 
     /**
      * List of named prefix copy of a paradigm
      */
-    map<wstring, map<wstring, int, Ltstr>, Ltstr> prefix_paradigms;
+    map<UString, map<UString, int>> prefix_paradigms;
 
     /**
      * List of named suffix copy of a paradigm
      */
-    map<wstring, map<wstring, int, Ltstr>, Ltstr> suffix_paradigms;
+    map<UString, map<UString, int>> suffix_paradigms;
 
     /**
      * List of named endings of a suffix copy of a paradgim
      */
-    map<wstring, map<wstring, int, Ltstr>, Ltstr> postsuffix_paradigms;
+    map<UString, map<UString, int>> postsuffix_paradigms;
 
+  template<typename... T>
+  void error(const char* fmt, T... args) {
+    UFILE* out = u_finit(stderr, NULL, NULL);
+    u_fprintf(out, "Error on line %d: ",
+              xmlTextReaderGetParserLineNumber(reader));
+    u_fprintf(out, fmt, args...);
+    u_fprintf(out, "\n");
+    exit(EXIT_FAILURE);
+  }
 
     /*
      static string range(char const a, char const b);
@@ -175,7 +193,7 @@ private:
      * @param name the name of the attribute
      * @return the value of the attribute
      */
-    wstring attrib(wstring const &name);
+    UString attrib(UString const &name);
 
     /**
      * Construct symbol pairs by align left side of both parts and insert
@@ -186,7 +204,7 @@ private:
      * @param t the transducer
      * @return the last state of the inserted transduction
      */
-    int matchTransduction(list<int> const &lp, list<int> const &rp,
+    int matchTransduction(vector<int> const &lp, vector<int> const &rp,
                           int state, Transducer &t);
     /**
      * Parse the &lt;p&lt; element
@@ -217,7 +235,7 @@ private:
      * @param name the name of the node
      * @param elem the name of the expected node
      */
-    void skip(wstring &name, wstring const &elem);
+    void skip(UString &name, UString const &elem);
 
     /**
      * Skip all document #text nodes before "elem"
@@ -225,22 +243,22 @@ private:
      * @param elem the name of the expected node
      * @param open true for open element, false for closed
      */
-    void skip(wstring &name, wstring const &elem, bool open);
+    void skip(UString &name, UString const &elem, bool open);
 
     /**
      * Skip all blank #text nodes before "name"
      * @param name the name of the node
      */
-    void skipBlanks(wstring &name);
+    void skipBlanks(UString &name);
 
 
-    void readString(list<int> &result, wstring const &name);
+    void readString(vector<int> &result, UString const &name);
 
     /**
      * Force an element to be empty, and check for it
      * @param name the element
      */
-    void requireEmptyError(wstring const &name);
+    void requireEmptyError(UString const &name);
 
     /**
      * Force an attribute to be specified, amd check for it
@@ -249,8 +267,8 @@ private:
      * @param elemname the parent of the attribute
      */
 
-    void requireAttribute(wstring const &value, wstring const &attrname,
-                          wstring const &elemname);
+    void requireAttribute(UString const &value, UString const &attrname,
+                          UString const &elemname);
     /**
      * True if all the elements in the current node are blanks
      * @return true if all are blanks
@@ -263,60 +281,55 @@ public:
      * Constants to represent the element and the attributes of
      * dictionaries
      */
-    static wstring const COMPILER_DICTIONARY_ELEM;
-    static wstring const COMPILER_ALPHABET_ELEM;
-    static wstring const COMPILER_SDEFS_ELEM;
-    static wstring const COMPILER_SDEF_ELEM;
-    static wstring const COMPILER_N_ATTR;
-    static wstring const COMPILER_PARDEFS_ELEM;
-    static wstring const COMPILER_PARDEF_ELEM;
-    static wstring const COMPILER_PAR_ELEM;
-    static wstring const COMPILER_ENTRY_ELEM;
-    static wstring const COMPILER_RESTRICTION_ATTR;
-    static wstring const COMPILER_RESTRICTION_LR_VAL;
-    static wstring const COMPILER_RESTRICTION_RL_VAL;
-    static wstring const COMPILER_PAIR_ELEM;
-    static wstring const COMPILER_LEFT_ELEM;
-    static wstring const COMPILER_RIGHT_ELEM;
-    static wstring const COMPILER_S_ELEM;
-    static wstring const COMPILER_REGEXP_ELEM;
-    static wstring const COMPILER_SECTION_ELEM;
-    static wstring const COMPILER_ID_ATTR;
-    static wstring const COMPILER_TYPE_ATTR;
-    static wstring const COMPILER_IDENTITY_ELEM;
-    static wstring const COMPILER_JOIN_ELEM;
-    static wstring const COMPILER_BLANK_ELEM;
-    static wstring const COMPILER_POSTGENERATOR_ELEM;
-    static wstring const COMPILER_GROUP_ELEM;
-    static wstring const COMPILER_LEMMA_ATTR;
-    static wstring const COMPILER_IGNORE_ATTR;
-    static wstring const COMPILER_IGNORE_YES_VAL;
-    static wstring const COMPILER_ALT_ATTR;
-    static wstring const COMPILER_V_ATTR;
-    static wstring const COMPILER_VL_ATTR;
-    static wstring const COMPILER_VR_ATTR;
+    static UString const COMPILER_DICTIONARY_ELEM;
+    static UString const COMPILER_ALPHABET_ELEM;
+    static UString const COMPILER_SDEFS_ELEM;
+    static UString const COMPILER_SDEF_ELEM;
+    static UString const COMPILER_N_ATTR;
+    static UString const COMPILER_PARDEFS_ELEM;
+    static UString const COMPILER_PARDEF_ELEM;
+    static UString const COMPILER_PAR_ELEM;
+    static UString const COMPILER_ENTRY_ELEM;
+    static UString const COMPILER_RESTRICTION_ATTR;
+    static UString const COMPILER_RESTRICTION_LR_VAL;
+    static UString const COMPILER_RESTRICTION_RL_VAL;
+    static UString const COMPILER_PAIR_ELEM;
+    static UString const COMPILER_LEFT_ELEM;
+    static UString const COMPILER_RIGHT_ELEM;
+    static UString const COMPILER_S_ELEM;
+    static UString const COMPILER_REGEXP_ELEM;
+    static UString const COMPILER_SECTION_ELEM;
+    static UString const COMPILER_ID_ATTR;
+    static UString const COMPILER_TYPE_ATTR;
+    static UString const COMPILER_IDENTITY_ELEM;
+    static UString const COMPILER_JOIN_ELEM;
+    static UString const COMPILER_BLANK_ELEM;
+    static UString const COMPILER_POSTGENERATOR_ELEM;
+    static UString const COMPILER_GROUP_ELEM;
+    static UString const COMPILER_LEMMA_ATTR;
+    static UString const COMPILER_IGNORE_ATTR;
+    static UString const COMPILER_IGNORE_YES_VAL;
+    static UString const COMPILER_ALT_ATTR;
+    static UString const COMPILER_V_ATTR;
+    static UString const COMPILER_VL_ATTR;
+    static UString const COMPILER_VR_ATTR;
 
-    static wstring const COMPILER_ANYTAG_ELEM;
-    static wstring const COMPILER_ANYCHAR_ELEM;
-    static wstring const COMPILER_WB_ELEM;
+    static UString const COMPILER_ANYTAG_ELEM;
+    static UString const COMPILER_ANYCHAR_ELEM;
+    static UString const COMPILER_WB_ELEM;
+    static UString const COMPILER_SPACE_ATTR;
+    static UString const COMPILER_SPACE_YES_VAL;
+    static UString const COMPILER_SPACE_NO_VAL;
+    static UString const SYMBOL_WB_SPACE;
+    static UString const SYMBOL_WB_NO_SPACE;
 
 
-    /**
-     * Constructor
-     */
-    Compiler();
-
-    /**
-     * Destructor
-     */
-    ~Compiler();
-
     /**
      * Compile dictionary to letter transducers
      * @param fichero file
      * @param dir direction
      */
-    void parse(string const &fichero, wstring const &dir);
+    void parse(string const &fichero, UString const &dir);
 
     //  auto getAlt();
     //  auto getInt();
